from collections import OrderedDict

from faker.typing import OrderedDictType

from .. import Provider as ColorProvider

localized = True


class Provider(ColorProvider):
    """
    Color provider for ``de`` locale. Source: https://www.sttmedia.com/colornames
    """

    all_colors: OrderedDictType[str, str] = OrderedDict(
        (
            ("Eisfarben", "#F0F8FF"),
            ("Antikweiß", "#FAEBD7"),
            ("Wasser", "#00FFFF"),
            ("Aquamarinblau", "#7FFFD4"),
            ("Azur", "#F0FFFF"),
            ("Beige", "#F5F5DC"),
            ("Biskuit", "#FFE4C4"),
            ("Schwarz", "#000000"),
            ("Mandelweiß", "#FFEBCD"),
            ("Blau", "#0000FF"),
            ("Blauviolett", "#8A2BE2"),
            ("Braun", "#A52A2A"),
            ("Gelbbraun", "#DEB887"),
            ("Kadettenblau", "#5F9EA0"),
            ("Hellgrün", "#7FFF00"),
            ("Schokolade", "#D2691E"),
            ("Koralle", "#FF7F50"),
            ("Kornblumenblau", "#6495ED"),
            ("Mais", "#FFF8DC"),
            ("Karminrot", "#DC143C"),
            ("Cyan", "#00FFFF"),
            ("Dunkelblau", "#00008B"),
            ("Dunkelcyan", "#008B8B"),
            ("Dunkle Goldrutenfarbe", "#B8860B"),
            ("Dunkelgrau", "#A9A9A9"),
            ("Dunkelgrün", "#006400"),
            ("Dunkelkhaki", "#BDB76B"),
            ("Dunkelmagenta", "#8B008B"),
            ("Dunkles Olivgrün", "#556B2F"),
            ("Dunkles Orange", "#FF8C00"),
            ("Dunkle Orchidee", "#9932CC"),
            ("Dunkelrot", "#8B0000"),
            ("Dunkle Lachsfarbe", "#E9967A"),
            ("Dunkles Seegrün", "#8FBC8F"),
            ("Dunkles Schieferblau", "#483D8B"),
            ("Dunkles Schiefergrau", "#2F4F4F"),
            ("Dunkeltürkis", "#00CED1"),
            ("Dunkelviolett", "#9400D3"),
            ("Tiefrosa", "#FF1493"),
            ("Tiefes Himmelblau", "#00BFFF"),
            ("Trübes Grau", "#696969"),
            ("Persenningblau", "#1E90FF"),
            ("Backstein", "#B22222"),
            ("Blütenweiß", "#FFFAF0"),
            ("Waldgrün", "#228B22"),
            ("Fuchsia", "#FF00FF"),
            ("Gainsboro", "#DCDCDC"),
            ("Geisterweiß", "#F8F8FF"),
            ("Gold", "#FFD700"),
            ("Goldrute", "#DAA520"),
            ("Grau", "#808080"),
            ("Grün", "#008000"),
            ("Grüngelb", "#ADFF2F"),
            ("Honigmelone", "#F0FFF0"),
            ("Leuchtendes Rosa", "#FF69B4"),
            ("Indischrot", "#CD5C5C"),
            ("Indigo", "#4B0082"),
            ("Elfenbein", "#FFFFF0"),
            ("Khaki", "#F0E68C"),
            ("Lavendel", "#E6E6FA"),
            ("Lavendelrosa", "#FFF0F5"),
            ("Rasengrün", "#7CFC00"),
            ("Chiffongelb", "#FFFACD"),
            ("Hellblau", "#ADD8E6"),
            ("Helles Korallenrot", "#F08080"),
            ("Helles Cyan", "#E0FFFF"),
            ("Helles Goldrutengelb", "#FAFAD2"),
            ("Hellgrau", "#D3D3D3"),
            ("Hellgrün", "#90EE90"),
            ("Hellrosa", "#FFB6C1"),
            ("Helle Lachsfarbe", "#FFA07A"),
            ("Helles Seegrün", "#20B2AA"),
            ("Helles Himmelblau", "#87CEFA"),
            ("Helles Schiefergrau", "#778899"),
            ("Helles Stahlblau", "#B0C4DE"),
            ("Hellgelb", "#FFFFE0"),
            ("Limone", "#00FF00"),
            ("Limonengrün", "#32CD32"),
            ("Leinen", "#FAF0E6"),
            ("Magenta", "#FF00FF"),
            ("Kastanie", "#800000"),
            ("Mittleres Aquamarin", "#66CDAA"),
            ("Mittleres Blau", "#0000CD"),
            ("Mittlere Orchidee", "#BA55D3"),
            ("Mittleres Violett", "#9370DB"),
            ("Mittleres Seegrün", "#3CB371"),
            ("Mittleres Schieferblau", "#7B68EE"),
            ("Mittleres Frühlingsgrün", "#00FA9A"),
            ("Mittleres Türkis", "#48D1CC"),
            ("Mittleres Violettrot", "#C71585"),
            ("Mitternachtsblau", "#191970"),
            ("Minzcreme", "#F5FFFA"),
            ("Altrosa", "#FFE4E1"),
            ("Mokassin", "#FFE4B5"),
            ("Navajoweiß", "#FFDEAD"),
            ("Marineblau", "#000080"),
            ("Alte Spitze", "#FDF5E6"),
            ("Olivgrün", "#808000"),
            ("Olivgraubraun", "#6B8E23"),
            ("Orange", "#FFA500"),
            ("Orangerot", "#FF4500"),
            ("Orchidee", "#DA70D6"),
            ("Blasse Goldrutenfarbe", "#EEE8AA"),
            ("Blassgrün", "#98FB98"),
            ("Blasstürkis", "#AFEEEE"),
            ("Blasses Violetrot", "#DB7093"),
            ("Papayacreme", "#FFEFD5"),
            ("Pfirsich", "#FFDAB9"),
            ("Peru", "#CD853F"),
            ("Rosa", "#FFC0CB"),
            ("Pflaume", "#DDA0DD"),
            ("Taubenblau", "#B0E0E6"),
            ("Lila", "#800080"),
            ("Rot", "#FF0000"),
            ("Rosiges Braun", "#BC8F8F"),
            ("Königsblau", "#4169E1"),
            ("Sattelbraun", "#8B4513"),
            ("Lachsfarben", "#FA8072"),
            ("Sandbraun", "#F4A460"),
            ("Seegrün", "#2E8B57"),
            ("Muschelfarben", "#FFF5EE"),
            ("Siennaerde", "#A0522D"),
            ("Silber", "#C0C0C0"),
            ("Himmelblau", "#87CEEB"),
            ("Schieferblau", "#6A5ACD"),
            ("Schiefergrau", "#708090"),
            ("Schneeweiß", "#FFFAFA"),
            ("Frühlingsgrün", "#00FF7F"),
            ("Stahlblau", "#4682B4"),
            ("Hautfarben", "#D2B48C"),
            ("Petrol", "#008080"),
            ("Distel", "#D8BFD8"),
            ("Tomatenrot", "#FF6347"),
            ("Türkis", "#40E0D0"),
            ("Violett", "#EE82EE"),
            ("Weizen", "#F5DEB3"),
            ("Weiß", "#FFFFFF"),
            ("Rauchfarben", "#F5F5F5"),
            ("Gelb", "#FFFF00"),
            ("Gelbgrün", "#9ACD32"),
        )
    )



from .. import Provider as InternetProvider


class Provider(InternetProvider):
    user_name_formats = (
        "{{last_name_female}}.{{first_name_female}}",
        "{{last_name_male}}.{{first_name_male}}",
        "{{first_name_female}}.{{last_name_female}}",
        "{{first_name_male}}.{{last_name_male}}",
        "{{first_name}}##",
        "{{first_name}}_##",
        "?{{last_name}}",
        "{{first_name}}{{year}}",
        "{{first_name}}_{{year}}",
    )

    email_formats = ("{{user_name}}@{{free_email_domain}}", "{{user_name}}@{{domain_name}}")

    free_email_domains = ("gmail.com", "yahoo.com", "hotmail.com", "mail.ru", "yandex.ru", "box.az", "amail.az")

    tlds = ("az", "com", "biz", "info", "net", "org", "edu")

    replacements = (
        ("Ə", "e"),
        ("I", "i"),
        ("Ü", "u"),
        ("Ş", "sh"),
        ("Ç", "c"),
        ("Ğ", "g"),
        ("Ö", "o"),
        ("ə", "e"),
        ("ı", "i"),
        ("ü", "u"),
        ("ş", "sh"),
        ("ç", "c"),
        ("ğ", "g"),
        ("ö", "o"),
    )



from .. import Provider as BaseProvider


# Reference:
# https://th.wikipedia.org/wiki/หมวดหมู่:บุคคลแบ่งตามอาชีพ
# on 2018-10-16, slightly edited and add few more jobs
class Provider(BaseProvider):
    jobs = (
        "กวี",
        "เกษตรกร",
        "ข้าราชการ",
        "คนขับรถแท็กซี่",
        "ค้าขาย",
        "โฆษก",
        "จ๊อกกี้",
        "จิตรกร",
        "เจ้าหน้าที่พัฒนาเอกชน",
        "เจ้าหน้าทีรักษาความปลอดภัย",
        "เจ้าหน้าที่รัฐบาล",
        "ช่างทำเครื่องดนตรี",
        "ช่างทำผม",
        "ตำรวจ",
        "ทนายความ",
        "ทหารบก",
        "นักกฎหมาย",
        "นักการกุศล",
        "นักการทูต",
        "นักการเมือง",
        "นักการศึกษา",
        "นักกีฬา",
        "นักเขียน",
        "นักคณิตศาสตร์",
        "นักเคลื่อนไหว",
        "นักจัดรายการวิทยุ",
        "นักจิตวิทยา",
        "นักชีววิทยา",
        "นักดนตรี",
        "นักดาราศาสตร์",
        "นักแต่งเพลง",
        "นักถ่ายภาพ",
        "นักธุรกิจ",
        "นักบวช",
        "นักบิน",
        "นักบินอวกาศ",
        "นักโบราณคดี",
        "นักประชาสัมพันธ์",
        "นักประดิษฐ์",
        "นักประวัติศาสตร์",
        "นักปรัชญา",
        "นักแปล",
        "นักผจญภัย",
        "นักพจนานุกรม",
        "นักพากย์",
        "นักภาษาศาสตร์",
        "นักโภชนาการ",
        "นักมายากล",
        "นักวาดการ์ตูน",
        "นักวิจัย",
        "นักวิทยาศาสตร์",
        "นักเศรษฐศาสตร์",
        "นักสะสมศิลปะ",
        "นักสังคมวิทยา",
        "นักสังคมศาสตร์",
        "นักสังคมสงเคราะห์",
        "นักสัตววิทยา",
        "นักสำรวจ",
        "นักสิทธิมนุษยชน",
        "นักสืบ",
        "นักแสดง",
        "นักหนังสือพิมพ์",
        "นักอนุรักษ์ธรรมชาติ",
        "นักออกแบบ",
        "นางแบบ",
        "นายแบบ",
        "บรรณาธิการ",
        "บรรณารักษ์",
        "โปรแกรมเมอร์",
        "ผู้กำกับ",
        "ผู้กำกับภาพยนตร์",
        "ผู้กำกับละครโทรทัศน์",
        "ผู้จัดพิมพ์",
        "พิธีกร",
        "แพทย์",
        "ภัณฑารักษ์",
        "เภสัชกร",
        "มัคคุเทศก์",
        "วิศวกร",
        "วีเจ",
        "ศิลปิน",
        "สถาปนิก",
        "อัยการ",
        "อาจารย์",
    )
